@@ -1,12 +1,33 @@
 import argparse
+
 from eda_report.read_file import df_from_file
 
 
 def process_cli_args():
-    """This function creates the positional and optional arguments for the
-    command line interface, and also parses input from the command line.
+    """Captures and parses input from the command line interface.
 
-    It uses the `argparse`_ module from the Python standard library.
+    The `argparse`_ module from the Python standard library is used to define
+    the *positional* and *optional arguments*.
+
+    Available options are::
+
+        usage: eda_cli [-h] [-o OUTFILE] [-t TITLE] [-c COLOR] infile
+
+        Get a basic EDA report in docx format.
+
+        positional arguments:
+          infile                A .csv or .xlsx file to process.
+
+        optional arguments:
+          -h, --help            show this help message and exit
+          -o OUTFILE, --outfile OUTFILE
+                                The output file (default: eda-report.docx)
+          -t TITLE, --title TITLE
+                                The top level heading in the report (default:
+                                Exploratory Data Analysis Report)
+          -c COLOR, --color COLOR
+                                A valid matplotlib color specifier (default:
+                                orangered)
 
     .. _`argparse`: https://docs.python.org/3/library/argparse.html
     """
