@@ -3,16 +3,19 @@ from io import BytesIO
 import matplotlib
 from matplotlib.figure import Figure
 
+
 # Matplotlib configuration
 matplotlib.rcParams['figure.dpi'] = 150  # resolution (dots per inch)
 matplotlib.rcParams['figure.autolayout'] = True  # tight layout
-matplotlib.rcParams['savefig.transparent'] = False   # transparent background
-matplotlib.rcParams["savefig.edgecolor"] = 'k'  # black frame
+matplotlib.rcParams['savefig.transparent'] = False  # transparent background
+matplotlib.rcParams['savefig.edgecolor'] = 'k'  # black frame
+matplotlib.rcParams['savefig.facecolor'] = 'w'  # white background
 matplotlib.rcParams['font.family'] = 'serif'
 matplotlib.rcParams['axes.spines.top'] = False  # remove top spine
 matplotlib.rcParams['axes.spines.right'] = False  # remove left spine
 matplotlib.use('agg')  # use non-interactive matplotlib back-end
 
+
 Fig = Figure
 
 
