@@ -1,11 +1,14 @@
 import seaborn as sns
+from pandas.api.types import is_bool_dtype, is_numeric_dtype
+from PIL import Image
+
 from eda_report.plotting import Fig, savefig
-from pandas.api.types import is_numeric_dtype, is_bool_dtype
+from eda_report.validate import validate_univariate_input
 
 
 class Variable:
     """This is the blueprint for structures to hold the contents and
-        characteristics of each column(variable) in a dataset.
+    characteristics of *individual columns/features*.
     """
 
     def __init__(self, data, graph_color='orangered', name=None):
@@ -16,29 +19,39 @@ class Variable:
         :param graph_color: The color to apply to the graphs created,
             defaults to 'orangered'.
         :type graph_color: str, optional
-        :param name: The name to give the variable.
+        :param name: The feature's name.
         :type name: str, optional
         """
-        self.data = data
-        #: The name of the variable.
+        self.data = validate_univariate_input(data)
+        #: The *name* of the *column/feature*. If unspecified in the name
+        #: argument during instantiation, this will be taken as the value of
+        #: the ``name`` attribute of the input data.
         self.name = name if name is not None else self.data.name
-        #: The variable's type.
+        #: The *column/feature*'s *type*; either *categorical* or *numeric*.
         self.var_type = self._get_variable_type()
-        #: Summary statistics for the variable, as a ``pandas.Series``.
+        #: *Summary statistics* for the *column/feature*, as a
+        #: ``pandas.Series``.
         self.statistics = self._get_summary_statictics()
-        #: The number of unique values in the variable.
+        #: The *number of unique values* in the *column/feature*.
         self.num_unique = self.data.nunique()
-        #: Unique values in the variable.
+        #: The *unique values* in the *column/feature*.
         self.unique = self.data.unique()
-        #: The number of missing values.
+        #: The number of *missing values* (``NaN``, ``None``, ``NA``, ...).
         self.missing = self._get_missing_values()
-        #: The color to apply to the created graphs.
-        self.GRAPH_COLOR = graph_color
-        #: The graphs for the variable as bytes in a file-like object.
-        self.graphs = self._plot_graphs()
+        #: The *color* applied to the created graphs.
+        self.graph_color = graph_color
+        # The *graphs* for the *column/feature* as bytes in a file-like object.
+        self._graphs = self._plot_graphs()
+
+    def show_graphs(self):
+        """Display the graphs for the *column/feature* using the :class:`PIL.Image`
+        class.
+        """
+        image = Image.open(self._graphs)
+        image.show()
 
     def _get_missing_values(self):
-        """Get the number of missing values in the data.
+        """Get the number of missing values in the **column/feature**.
         """
         missing_values = self.data.isna().sum()
         if missing_values == 0:
@@ -60,7 +73,7 @@ class Variable:
             return 'categorical'
 
     def _get_summary_statictics(self):
-        """Get summary statistics for the variable as a pandas Series.
+        """Get summary statistics for the column/feature as a pandas Series.
         """
         if self.var_type == 'numeric':
             return self._numeric_summary_statictics()
@@ -68,7 +81,7 @@ class Variable:
             return self._categorical_summary_statictics()
 
     def _plot_graphs(self):
-        """Plot graphs for the variable, based on variable type.
+        """Plot graphs for the column/feature, based on variable type.
         """
         if self.var_type == 'numeric':
             return self._plot_numeric()
@@ -76,7 +89,7 @@ class Variable:
             return self._plot_categorical()
 
     def _numeric_summary_statictics(self):
-        """Get summary statistics for a numeric variable.
+        """Get summary statistics for a numeric column/feature.
         """
         summary = self.data.describe()
         summary.index = [
@@ -88,7 +101,7 @@ class Variable:
         return summary.round(7)
 
     def _categorical_summary_statictics(self):
-        """Get summary statistics for a categorical variable.
+        """Get summary statistics for a categorical column/feature.
         """
         summary = self.data.describe()[['count', 'unique', 'top']]
         summary.index = ['Number of observations', 'Unique values',
@@ -101,7 +114,7 @@ class Variable:
         return summary
 
     def _plot_numeric(self):
-        """Get a boxplot and a histogram for a numeric variable.
+        """Get a boxplot and a histogram for a numeric column/feature.
         """
         fig = Fig(figsize=(6, 6), linewidth=1)
         ax1, ax2 = fig.subplots(2, 1)
@@ -112,18 +125,18 @@ class Variable:
         ax1.set_title(f'Box-plot of {self.name}', size=12)
         # Histogram
         ax2.set_title(f'Distribution plot of {self.name}', size=12)
-        sns.histplot(x=self.data, kde=True, ax=ax2, color=self.GRAPH_COLOR)
+        sns.histplot(x=self.data, kde=True, ax=ax2, color=self.graph_color)
 
         return savefig(fig)
 
     def _plot_categorical(self, color='cyan'):
-        """Get a bar-plot for a categorical variable.
+        """Get a bar-plot for a categorical column/feature.
         """
         fig = Fig(figsize=(6, 4), linewidth=1)
         ax = fig.subplots()
 
         self.data.value_counts().nlargest(10).plot.bar(
-            color=self.GRAPH_COLOR, ax=ax
+            color=self.graph_color, ax=ax
         )
         ax.tick_params(axis='x', rotation=45)
         ax.set_title(f'Bar-plot of {self.name}', size=12)
